==> jc-1.4.0.tar.gz: soot/jimple/parser/node/AShortBaseType.h <==
// public final class soot.jimple.parser.node.AShortBaseType

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 1d9a7b09c0401544 soot_jimple_parser_node_AShortBaseType
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 5816fe0bb21d8c7b soot_jimple_parser_node_PBaseType

// header file dependencies
// @dep_header soot_jimple_parser_node_PBaseType

#include "soot/jimple/parser/node/PBaseType.h"

#ifndef _JC_soot_jimple_parser_node_AShortBaseType_H_
#define _JC_soot_jimple_parser_node_AShortBaseType_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TShort$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AShortBaseType$sub_refs	_jc_soot_jimple_parser_node_AShortBaseType$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AShortBaseType$sub_nonrefs	_jc_soot_jimple_parser_node_AShortBaseType$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AShortBaseType$refs	_jc_soot_jimple_parser_node_AShortBaseType$refs;
typedef struct _jc_soot_jimple_parser_node_AShortBaseType$nonrefs	_jc_soot_jimple_parser_node_AShortBaseType$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AShortBaseType$object	_jc_soot_jimple_parser_node_AShortBaseType$object;

typedef const struct _jc_soot_jimple_parser_node_AShortBaseType$vmethods	_jc_soot_jimple_parser_node_AShortBaseType$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AShortBaseType$vtable	_jc_soot_jimple_parser_node_AShortBaseType$vtable;
typedef const struct _jc_soot_jimple_parser_node_AShortBaseType$vtype	_jc_soot_jimple_parser_node_AShortBaseType$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AShortBaseType$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseType$object *);
extern void _jc_soot_jimple_parser_node_AShortBaseType$method$_init$23f43e9289eb1226(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseType$object *, struct _jc_soot_jimple_parser_node_TShort$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_AShortBaseType$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseType$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AShortBaseType$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseType$object *);
extern struct _jc_soot_jimple_parser_node_TShort$object *_jc_soot_jimple_parser_node_AShortBaseType$method$getShort$7f2ee6a84e03e13a(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseType$object *);
extern void _jc_soot_jimple_parser_node_AShortBaseType$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AShortBaseType$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AShortBaseType$method$setShort$422df9f3be44e5aa(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseType$object *, struct _jc_soot_jimple_parser_node_TShort$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AShortBaseType$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseType$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AShortBaseType$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AShortBaseType$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AShortBaseType$method_info$getShort$7f2ee6a84e03e13a;
extern _jc_method _jc_soot_jimple_parser_node_AShortBaseType$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AShortBaseType$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AShortBaseType$method_info$setShort$422df9f3be44e5aa;
extern _jc_method _jc_soot_jimple_parser_node_AShortBaseType$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AShortBaseType$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseType$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseType$object *);
	struct _jc_soot_jimple_parser_node_TShort$object	*(*getShort$7f2ee6a84e03e13a)(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseType$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setShort$422df9f3be44e5aa)(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseType$object *, struct _jc_soot_jimple_parser_node_TShort$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseType$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_AShortBaseType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBaseType$vmethods	soot_jimple_parser_node_PBaseType;
	_jc_soot_jimple_parser_node_AShortBaseType$vmethods	soot_jimple_parser_node_AShortBaseType;
};

// Vtype
struct _jc_soot_jimple_parser_node_AShortBaseType$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AShortBaseType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AShortBaseType$sub_refs {
	struct _jc_soot_jimple_parser_node_TShort$object	*__5fshort__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AShortBaseType$refs {
    _jc_soot_jimple_parser_node_AShortBaseType$sub_refs	soot_jimple_parser_node_AShortBaseType;
    _jc_soot_jimple_parser_node_PBaseType$sub_refs	soot_jimple_parser_node_PBaseType;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AShortBaseType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AShortBaseType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBaseType$sub_nonrefs	soot_jimple_parser_node_PBaseType;
    _jc_soot_jimple_parser_node_AShortBaseType$sub_nonrefs	soot_jimple_parser_node_AShortBaseType;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AShortBaseType$object {
	_jc_soot_jimple_parser_node_AShortBaseType$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AShortBaseType$vtype	*vtype;
	_jc_soot_jimple_parser_node_AShortBaseType$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AShortBaseType$vtype _jc_soot_jimple_parser_node_AShortBaseType$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AShortBaseType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AShortBaseType$class_object;

#endif	/* _JC_soot_jimple_parser_node_AShortBaseType_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/AShortBaseType.h <==
// public final class soot.jimple.parser.node.AShortBaseType

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 1d9a7b09c0401544 soot_jimple_parser_node_AShortBaseType
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 5816fe0bb21d8c7b soot_jimple_parser_node_PBaseType

// header file dependencies
// @dep_header soot_jimple_parser_node_PBaseType

#include "soot/jimple/parser/node/PBaseType.h"

#ifndef _JC_soot_jimple_parser_node_AShortBaseType_H_
#define _JC_soot_jimple_parser_node_AShortBaseType_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TShort$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AShortBaseType$sub_refs	_jc_soot_jimple_parser_node_AShortBaseType$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AShortBaseType$sub_nonrefs	_jc_soot_jimple_parser_node_AShortBaseType$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AShortBaseType$refs	_jc_soot_jimple_parser_node_AShortBaseType$refs;
typedef struct _jc_soot_jimple_parser_node_AShortBaseType$nonrefs	_jc_soot_jimple_parser_node_AShortBaseType$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AShortBaseType$object	_jc_soot_jimple_parser_node_AShortBaseType$object;

typedef const struct _jc_soot_jimple_parser_node_AShortBaseType$vmethods	_jc_soot_jimple_parser_node_AShortBaseType$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AShortBaseType$vtable	_jc_soot_jimple_parser_node_AShortBaseType$vtable;
typedef const struct _jc_soot_jimple_parser_node_AShortBaseType$vtype	_jc_soot_jimple_parser_node_AShortBaseType$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AShortBaseType$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseType$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AShortBaseType$method$_init$23f43e9289eb1226(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseType$object *, struct _jc_soot_jimple_parser_node_TShort$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_AShortBaseType$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseType$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AShortBaseType$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseType$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TShort$object *_jc_soot_jimple_parser_node_AShortBaseType$method$getShort$7f2ee6a84e03e13a(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseType$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AShortBaseType$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AShortBaseType$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AShortBaseType$method$setShort$422df9f3be44e5aa(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseType$object *, struct _jc_soot_jimple_parser_node_TShort$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AShortBaseType$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseType$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AShortBaseType$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AShortBaseType$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AShortBaseType$method_info$getShort$7f2ee6a84e03e13a;
extern _jc_method _jc_soot_jimple_parser_node_AShortBaseType$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AShortBaseType$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AShortBaseType$method_info$setShort$422df9f3be44e5aa;
extern _jc_method _jc_soot_jimple_parser_node_AShortBaseType$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AShortBaseType$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseType$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseType$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TShort$object	*(*getShort$7f2ee6a84e03e13a)(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseType$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseType$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setShort$422df9f3be44e5aa)(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseType$object *, struct _jc_soot_jimple_parser_node_TShort$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AShortBaseType$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_AShortBaseType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBaseType$vmethods	soot_jimple_parser_node_PBaseType;
	_jc_soot_jimple_parser_node_AShortBaseType$vmethods	soot_jimple_parser_node_AShortBaseType;
};

// Vtype
struct _jc_soot_jimple_parser_node_AShortBaseType$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AShortBaseType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AShortBaseType$sub_refs {
	struct _jc_soot_jimple_parser_node_TShort$object	*__5fshort__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AShortBaseType$refs {
    _jc_soot_jimple_parser_node_AShortBaseType$sub_refs	soot_jimple_parser_node_AShortBaseType;
    _jc_soot_jimple_parser_node_PBaseType$sub_refs	soot_jimple_parser_node_PBaseType;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AShortBaseType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AShortBaseType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBaseType$sub_nonrefs	soot_jimple_parser_node_PBaseType;
    _jc_soot_jimple_parser_node_AShortBaseType$sub_nonrefs	soot_jimple_parser_node_AShortBaseType;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AShortBaseType$object {
	_jc_soot_jimple_parser_node_AShortBaseType$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AShortBaseType$vtype	*vtype;
	_jc_soot_jimple_parser_node_AShortBaseType$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AShortBaseType$vtype _jc_soot_jimple_parser_node_AShortBaseType$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AShortBaseType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AShortBaseType$class_object;

#endif	/* _JC_soot_jimple_parser_node_AShortBaseType_H_ */
